from setuptools import setup

setup(name='distributions_mg_1',
      version='0.1',
      description='Gaussian distributions',
      packages=['distributions_mg_1'],
      author='Matthew Gray',
      zip_safe=False)
